Module: Pinmark::Session

Extended by:
ActiveSupport::Concern
Defined in:
app/controllers/concerns/pinmark/session.rb

Overview

Wraps each request in a tracker so the Phlex/ViewComponent/ERB hooks can push/pop nodes. Activated by the ‘?annotate=1` query string or the `pinmark=1` cookie set by the activator partial.

Include this in any host controller whose responses should support annotations (typically the storefront base controller).